/*
 * monMsgIds.h --
 *
 *      Error catalog text file message Ids.
 *
 * Copyright(C) 1995, 1996 NEC Corporation. All rights reserved.
 * This is a genuine component of Socks5Toolkit(TM).
 *
 * $Header: /insg/project/socks/s5watch/include/monMsgIds.h,v 1.1 1996/10/02 19:41:36 miked Exp $
 * $Log: monMsgIds.h,v $
 * Revision 1.1  1996/10/02 19:41:36  miked
 * Added to Unix from Win/NT version.
 *
 */

#ifndef _H_MONMSGIDS
#define _H_MONMSGIDS

#define MSGID_MON_BAD_HANDLE            1
#define MSGID_MON_DUP_CLIENT            2
#define MSGID_MON_BAD_CLIENT            3
#define MSGID_MON_TOO_MANY_CLIENTS      4
#define MSGID_MON_OPEN_FMAP             5
#define MSGID_MON_CREATE_FMAP           6
#define MSGID_MON_FMAP                  7
#define MSGID_MON_REGISTRY_ERR          8
#define MSGID_MON_TOO_MANY_UDP          9
#define MSGID_MON_MEM_OPEN              10
#define MSGID_MON_FIFO_OPEN             11
#define MSGID_MON_WRITE                 12
#define MSGID_MON_READ                  13
#define MSGID_MON_INVALID_MSG           14
#define MSGID_MON_NET_OPEN              15
#define MSGID_MON_MUTEX_OPEN            16
#define MSGID_MON_FIFO_CONNECT          17
#define MSGID_MON_FIFO_CREATE           18
#define MSGID_MON_MUTEX_CREATE          19
#define MSGID_MON_SEND                  20
#define MSGID_MON_RECV                  21
#define MSGID_MON_CLOSE                 22
#define MSGID_MON_WSA                   24
#define MSGID_MON_SERVICE               25
#define MSGID_MON_STARTED               26
#define MSGID_MON_OPEN                  27
#define MSGID_MON_NO_DATA               28
#define MSGID_MON_MMAP_NOT_MAPPED       29
#define MSGID_MON_MMAP_NO_FREE_MEM      30
#define MSGID_MON_MMAP_UNMAP            31
#define MSGID_MON_MMAP_CLOSE            32
#define MSGID_MON_MMAP_CANT_FREE        33
#define MSGID_MON_MUTEX_CLOSE           34
#define MSGID_MON_HANDLE_MALLOC         35
#define MSGID_MON_BAD_MUTEX_NAME        36
#define MSGID_MON_NO_MUTEX              37
#define MSGID_MON_RELEASE_MUTEX         38
#define MSGID_MON_PERFMON_COUNTER       39
#define MSGID_MON_SECURITY_INFO         40
#define MSGID_MON_MALLOC                41
#define MSGID_MON_DUP_HANDLE            42
#define MSGID_MON_WSA_VER               43
#define MSGID_MON_DB_INIT               44
#define MSGID_MON_DB_REMOTEOPEN         45
#define MSGID_MON_DB_LOCALOPEN          46
#define MSGID_MON_DB_SENDDATA           47
#define MSGID_MON_DB_CLOSE              48
#define MSGID_MON_DBSCAN                49
#define MSGID_MON_FAILED                51

#endif /* _H_MONMSGIDS */
