/*
 *    stdafx.h - dummy "precompiled" header for Windows/NT compatibility
 *
 *    Only needs to be present on UNIX because some .c files renamed .cpp
 *    on Windows/NT must #include "stdafx.h".
 *
 * $Header: /insg/project/socks/s5watch/include/stdafx.h,v 1.1.1.1 1996/08/30 02:43:50 miked Exp $
 * $Log: stdafx.h,v $
 * Revision 1.1.1.1  1996/08/30 02:43:50  miked
 * Initial version.
 *
 * Revision 1.2  1996/07/09  23:57:52  miked
 * Added new copyright notice.
 *
 * Revision 1.1.1.1  1996/07/08  15:09:43  miked
 * Initial version for Socks5 API.
 */

#ifndef _H_STDAFX
#define _H_STDAFX
#endif
